@@ -244,7 +244,7 @@ def set_env(spark: SparkSession, profile_alias: str) -> None:
 
 
 def set_os_paths(
-    hadoop_home: str = None, java_home: str = None, pyspark_python: str = None
+    hadoop_home: str = "", java_home: str = "", pyspark_python: str = ""
 ) -> None:
     osp = OSPaths(
         hadoop_home=hadoop_home, java_home=java_home, pyspark_python=pyspark_python
